from datetime import datetime
from decimal import Decimal


class Product:
    """
    Represents a product in the system.

    :param id: The unique identifier of the product.
    :type id: int
    :param seller_id: The user ID of the seller.
    :type seller_id: int
    :param name: The name of the product.
    :type name: str
    :param price: The price of the product.
    :type price: Decimal
    :param creation_date: The date and time when the product was created.
    :type creation_date: datetime
    """

    def __init__(
        self,
        product_id: int = None,
        seller_id: int = None,
        seller_name: str = None,
        name: str = None,
        price: Decimal = None,
        creation_date: datetime = None,
    ):
        self.product_id = product_id
        self.seller_id = seller_id
        self.seller_name = seller_name
        self.name = name
        self.price = price
        self.creation_date = creation_date

    def __repr__(self):
        return f"Product(product_id={self.product_id}, seller_id={self.seller_id}, seller_name={self.seller_name}, name='{self.name}', price={self.price}, creation_date={self.creation_date!r})"
